/// ABBYY Mobile Capture © 2020 ABBYY Development, Inc.
/// ABBYY is a registered trademark or a trademark of ABBYY Software Ltd.

#import <UIKit/UIKit.h>
#import "AUICaptureScenario.h"
#import "AUICameraSettings.h"
#import "AUILocalizer.h"

NS_ASSUME_NONNULL_BEGIN

/// Controller for capture image. If created without initial view controller, pushes camera controller automatically.
ABBYYUI_EXTERN
@interface AUICaptureController : UINavigationController

/// Initializes AUICaptureController with specific AUICaptureScenario
///
/// This is an alternative to `initWithCoder:` which, in opposite, allows you to initialize AUICaptureController using UIStoryboard.
///
/// Use this method when a direct instance of the AUICaptureController is needed.
- (instancetype)initWithCaptureScenario:(AUICaptureScenario*)captureScenario;

/// Initializes AUICaptureController
///
/// This is an alternative to `initWithCoder:` which, in opposite, allows you to initialize AUICaptureController using UIStoryboard.
///
/// Use this method when a direct instance of the AUICaptureController is needed.
///
/// AUICaptureScenario must be provided for created AUICaptureController before any further AUICameraSettings setup.
- (instancetype)init;

- (instancetype)initWithNibName:(nullable NSString *)nibNameOrNil bundle:(nullable NSBundle *)nibBundleOrNil __attribute__((unavailable("Use -init or -initWithCaptureScenario: instead")));

- (instancetype)initWithRootViewController:(UIViewController *)rootViewController __attribute__((unavailable("Use -init or -initWithCaptureScenario: instead")));

- (instancetype)initWithNavigationBarClass:(nullable Class)navigationBarClass toolbarClass:(nullable Class)toolbarClass __attribute__((unavailable("Use -init or -initWithCaptureScenario: instead")));


/// Bundle for localized strings table AbbyyUI.strings.
@property (class, nonatomic, strong, null_resettable) id<AUILocalizer> localizer;

/// AbbyyCaptureScenario that controlls capture process.
@property (nonatomic, strong, nullable) AUICaptureScenario* captureScenario;

/// Camera overlay view. Shows over camera view.
/// To define in storyboard it must be placed outside AUICaptureController.
@property (nonatomic, strong, nullable) IBOutlet UIView* cameraOverlayView;

/// Camera torch toggle button. Selected state stores in NSUserDefaults.
@property (nonatomic, strong, nullable) IBOutlet UIButton* flashButton;
/// Determines whether or not flash button is hidden. Default values is NO.
@property (nonatomic, assign, getter=isFlashButtonHidden) BOOL flashButtonHidden;

/// Capture  button.
@property (nonatomic, strong, nullable) IBOutlet UIButton* captureButton;
/// Determines whether or not capture button is hidden. Default values is NO.
@property (nonatomic, assign, getter=isCaptureButtonHidden) BOOL captureButtonHidden;

/// Button to enable/disable auto-capture
@property (nonatomic, strong, nullable) IBOutlet UIButton* autoCaptureButton;
/// Determines whether or not auto-capture button is hidden. Default values is NO.
@property (nonatomic, assign, getter=isAutoCaptureButtonHidden) BOOL autoCaptureButtonHidden;

/// Pick image from gallery button.
@property (nonatomic, strong, nullable) IBOutlet UIButton* galleryButton;
/// Determines whether or not gallery button is hidden. Default values is NO.
@property (nonatomic, assign, getter=isGalleryButtonHidden) BOOL galleryButtonHidden;

/// Home button.
@property (nonatomic, strong, nullable) IBOutlet UIButton* homeButton;
/// Determines whether or not home button is hidden. Default values is NO.
@property (nonatomic, assign, getter=isHomeButtonHidden) BOOL homeButtonHidden;

/// Camera settings for current capture session. Nil if capture session not run.
@property (nonatomic, readonly, nullable) id<AUICameraSettings> cameraSettings;

/// Paused  state.
@property (nonatomic, assign) BOOL paused;

/// Set paused state with animation flag.
- (void)setPaused:(BOOL)paused animated:(BOOL)animated;

/// Push camera controller.
- (void)pushCameraControllerAnimated:(BOOL)animated;

/// Set or change capture scenario.
- (void)setCaptureScenario:(AUICaptureScenario*)captureScenario animated:(BOOL)animated;

@end

ABBYYUI_EXTERN
@interface UIView (AUIAnimationRotation)
/// Add this method to custom control and return YES to rotate according to device orientation on iPhone
- (BOOL)aui_canRotate;
@end

NS_ASSUME_NONNULL_END
