/// ABBYY Mobile Capture © 2020 ABBYY Development, Inc.
/// ABBYY is a registered trademark or a trademark of ABBYY Software Ltd.

#import <UIKit/UIKit.h>
#import "AUIDefinitions.h"
#import "AUICaptureResult.h"
#import "AUIImageObservationResult.h"

NS_ASSUME_NONNULL_BEGIN

@protocol AUICaptureScenarioDelegate;

ABBYYUI_EXTERN
@interface AUICaptureScenario : NSObject

@property (nonatomic, weak, nullable) id<AUICaptureScenarioDelegate> delegate;
/// Determines whether or not automatic image capturing is turned on. Default values is YES. Set NO to disable autocatic image capturing.
@property (nonatomic, assign, getter=isAutocaptureTurnedOn) BOOL autocaptureTurnedOn;
/// The result with scanned document.
@property (nonatomic, strong, readonly) id<AUICaptureResult> result;

/// Observe image. Call from main thread.
- (AUIImageObservationResult* _Nullable)observeUIImage:(UIImage*)image;

@end

@protocol AUICaptureScenarioDelegate <NSObject>

/**
 Tells the delegate that user denied access to camera and tapped to application settings button. Requires localization key CameraEnableCameraAccessInSystemSettingsRTF with underlined text that will be used as link and custom ``AUILocalizer``, see ``AUICaptureController/localizer``.
 
 @param captureScenario The capture scenario.
 */
- (void)captureScenarioDidRequestOpenAppSettings:(AUICaptureScenario*)captureScenario;

/**
 Tells the delegate that the user successfully saved document pages.

 @param captureScenario The capture scenario.
 @param sourceView View the scenario completion initiated from.
 */
- (void)captureScenarioDidComplete:(AUICaptureScenario*)captureScenario sourceView:(UIView* _Nullable)sourceView;

/**
 Tells the delegate that document scanning failed while the captureScenario was active. You are responsible for further actions: to delete scanned pages or to restore scenario.

 @param captureScenario The capture scenario.
 @param error The error containing the reason for failure.
 */
- (void)captureScenario:(AUICaptureScenario*)captureScenario didFailWithError:(NSError*)error;

/**
 Tells the delegate that the user cancelled scan action.

 @param captureScenario The capture scenario.
 */

- (void)captureScenarioDidClose:(AUICaptureScenario*)captureScenario;

@end

NS_ASSUME_NONNULL_END
