/// ABBYY Mobile Capture © 2020 ABBYY Development, Inc.
/// ABBYY is a registered trademark or a trademark of ABBYY Software Ltd.

#import <Foundation/Foundation.h>
#import "AUIMultiPageCaptureScenario.h"
#import "AUIImageCaptureSettings.h"
#import "AUIPageStorage.h"
#import "AUIAreaOfInterest.h"

NS_ASSUME_NONNULL_BEGIN

@class RTREngine;

#pragma mark -

@class AUIMultiPageImageCaptureScenario;

@protocol AUIMultiPageImageCaptureDelegate <AUICaptureScenarioDelegate>
/**
 Provides access to image capture settings

 @param captureScenario Capture scenario informing delegate.
 @param settings settings that can be specialized for the current page.
 @param index current page index.
 */
- (void)captureScenario:(AUIMultiPageImageCaptureScenario*)captureScenario
    onConfigureImageCaptureSettings:(id<AUIImageCaptureSettings>)settings
    forPageAtIndex:(NSUInteger)index;

@end

#pragma mark -

/**
 Capture scenario to capture images of multi page documents.
 Scenario result conforms to ``AUIMultiPageImageCaptureResult``.
 */
ABBYYUI_EXTERN
@interface AUIMultiPageImageCaptureScenario : AUIMultiPageCaptureScenario

/// Creates scenario with a valid engine and storage of image data.
- (instancetype)initWithEngine:(RTREngine*)engine pageStorage:(id<AUIPageStorage>)storage NS_DESIGNATED_INITIALIZER;
/// Creates scenario with default AUIPageStorage based on the file system.
- (nullable instancetype)initWithEngine:(RTREngine*)engine storagePath:(NSString*)path error:(NSError**)error;

+ (instancetype)new __unavailable;
- (instancetype)init __unavailable;

@end

NS_ASSUME_NONNULL_END
