/// ABBYY® Mobile Capture © 2019 ABBYY Production LLC.
/// ABBYY is a registered trademark or a trademark of ABBYY Software Ltd.

#import "AUIDefinitions.h"
#import "AUIConstants.h"
#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN

/**
 ENUM describing with which order the pages will be used in the Abbyy UI.
 */
typedef NS_ENUM(NSUInteger, AUIPageOrderingType) {
    /// Indexed means that access to the pages can be made by specific index of the record
    AUIPageOrderingTypeIndexed,
    /// Natural means that access to the pages will be ordered in ascending way and the pages will be always presented in the ascending order.
    AUIPageOrderingTypeNatural,
};

/**
 Object encapsulating OrderingType.
 */
ABBYYUI_EXTERN
@interface AUIPageStorageDataOrdering: NSObject <NSCopying>

@property (nonatomic, assign, readonly) AUIPageOrderingType type;
@property (nonatomic, assign, readonly) NSInteger value;

/// Initializes AUIPageStorageDataOrdering attribute for page's attributes
- (instancetype)initWithType:(AUIPageOrderingType)type andValue:(NSInteger)value;

@end

/**
 Object encapsulating Page's attributes and used as DTO object between Abbyy UI and the concrete AUIPageStorage implementation.
 */
ABBYYUI_EXTERN
@interface AUIPageAttributes : NSObject <NSCopying>

/// Array of CGPoint values wrapped in NSValue
///
/// Describes original image's boundary
@property (nonatomic, strong, readonly) NSArray<NSValue*>* originalImageBoundary;

/// Describes original image's size
@property (nonatomic, assign, readonly) CGSize originalImageSize;

/// Array of CGPoint values wrapped in NSValue
///
/// Describes cropped image's size
@property (nonatomic, strong, readonly) NSArray<NSValue*>* croppedImageBoundary;

/// Describes cropped image's size
@property (nonatomic, assign, readonly) CGSize croppedImageSize;

/// Describes rotation applied to cropped image. Could be one of four values: 0, 90, 180, 270
@property (nonatomic, assign, readonly) NSInteger croppedImageRotationAngle;

/// Object encapsulating OrderingType.
@property (nonatomic, strong, readonly) AUIPageStorageDataOrdering* ordering;

/// Describes document's size
@property (nonatomic, assign, readonly) AUIDocumentSize documentSize;

- (instancetype)initWithOriginalImageBoundary:(NSArray<NSValue*>*)originalImageBoundary
                            originalImageSize:(CGSize)originalImageSize
                         croppedImageBoundary:(NSArray<NSValue*>*)croppedImageBoundary
                             croppedImageSize:(CGSize)croppedImageSize
                    croppedImageRotationAngle:(NSInteger)croppedImageRotationAngle
                                     ordering:(AUIPageStorageDataOrdering*)ordering
                                 documentSize:(AUIDocumentSize)documentSize;

@end

NS_ASSUME_NONNULL_END
