/// ABBYY Mobile Capture © 2020 ABBYY Development, Inc.
/// ABBYY is a registered trademark or a trademark of ABBYY Software Ltd.

#import <Foundation/Foundation.h>
#import "AUIMultiPageCaptureScenario.h"
#import "AUISelfieCaptureSettings.h"

NS_ASSUME_NONNULL_BEGIN

@class AUISelfieCaptureScenario;

@protocol AUISelfieCaptureScenarioDelegate <AUICaptureScenarioDelegate>
/**
 Provides access to image capture settings

 @param captureScenario Capture scenario informing delegate.
 @param settings settings that can be specialized for the current page.
 @param index current page index.
 */
- (void)captureScenario:(AUISelfieCaptureScenario*)captureScenario
    onConfigureCaptureSettings:(id<AUISelfieCaptureSettings>)settings
    forPageAtIndex:(NSUInteger)index;

@end

/// Capture scenario to capture selfie.
ABBYYUI_EXTERN
@interface AUISelfieCaptureScenario : AUIMultiPageCaptureScenario

/// Capture settings.
@property(nonatomic, strong, readonly) id<AUISelfieCaptureSettings> settings;
/// Creates scenario with storage of image data.
- (instancetype)initWithPageStorage:(id<AUIPageStorage>)storage;
/// Creates scenario with default AUIPageStorage based on the file system.
- (instancetype)initWithStoragePath:(NSString*)path error:(NSError**)error;

@end

NS_ASSUME_NONNULL_END
